==> Paws-0.28.tar.gz: Paws-0.28/lib/Paws/CloudWatchEvents/EnableRule.pm <==

package Paws::CloudWatchEvents::EnableRule;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'EnableRule');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchEvents::EnableRule - Arguments for method EnableRule on Paws::CloudWatchEvents

=head1 DESCRIPTION

This class represents the parameters used for calling the method EnableRule on the 
Amazon CloudWatch Events service. Use the attributes of this class
as arguments to method EnableRule.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to EnableRule.

As an example:

  $service_obj->EnableRule(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

The name of the rule that you want to enable.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method EnableRule in L<Paws::CloudWatchEvents>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.31.tar.gz: Paws-0.31/lib/Paws/CloudWatchEvents/EnableRule.pm <==

package Paws::CloudWatchEvents::EnableRule;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'EnableRule');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchEvents::EnableRule - Arguments for method EnableRule on Paws::CloudWatchEvents

=head1 DESCRIPTION

This class represents the parameters used for calling the method EnableRule on the 
Amazon CloudWatch Events service. Use the attributes of this class
as arguments to method EnableRule.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to EnableRule.

As an example:

  $service_obj->EnableRule(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

The name of the rule that you want to enable.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method EnableRule in L<Paws::CloudWatchEvents>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
